ValueNode class

Represents a value node in the AST.

Inheritance

Constructors

ValueNode(String value, String? raw)
Constructor for the ValueNode class.

Properties

hashCode int
The hash code for this object.
no setterinherited
loc ValidationLocation?
The location of the node within the input source.
getter/setter pairinherited
parent Node?
Reference to the parent node, useful for traversing the AST.
getter/setter pairinherited
path String
The path to the node in the AST.
getter/setter pairinherited
raw String?
The raw value of the node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The node type.
finalinherited
value String
The value of the node.
final

Methods

extractProfileNodes() List<LiteralNode>
Extracts "profile" nodes from the meta section of the AST.
inherited
getPropertyNode(String propertyName) Node?
Gets a child node associated with a given property name in an object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printNode({int depth = 0}) String
Prints the node and its children in a hierarchical format.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override