Node class
Base class representing a node in the abstract syntax tree (AST).
- Implementers
Constructors
- Node(String type, {ValidationLocation? loc, Node? parent})
- Constructor for the Node class.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loc ↔ ValidationLocation?
-
The location of the node within the input source.
getter/setter pair
- parent ↔ Node?
-
Reference to the parent node, useful for traversing the AST.
getter/setter pair
- path ↔ String
-
The path to the node in the AST.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The node type.
final
Methods
-
extractProfileNodes(
) → List< LiteralNode> - Extracts "profile" nodes from the meta section of the AST.
-
getPropertyNode(
String propertyName) → Node? - Gets a child node associated with a given property name in an object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printNode(
{int depth = 0}) → String - Prints the node and its children in a hierarchical format.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited